CurrencyBalance class

Constructors

CurrencyBalance({required String currencyId, required String key, required int balance, required DateTime updatedAt})
CurrencyBalance.fromJson(Map<String, dynamic> json)
factory

Properties

balance int
final
currencyId String
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited