LeaderboardsNamespace class

Constructors

LeaderboardsNamespace(AmbaBindings _bindings)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

entries(String key, {int? limit}) Future<List<LeaderboardEntry>>
get(String key) Future<Leaderboard>
myRank(String key) Future<LeaderboardEntry>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited