MediaAsset class

Storage asset metadata returned by storage.list, storage.commit, storage.upload. Mirrors the MediaAsset wire shape.

Constructors

MediaAsset({required String id, required String bucket, required String key, required String url, required String mimeType, required int sizeBytes, int? width, int? height, int? retentionDays, required DateTime createdAt})
MediaAsset.fromJson(Map<String, dynamic> json)
factory

Properties

bucket String
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
id String
final
key String
final
mimeType String
final
retentionDays int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes int
final
url String
final
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited