OnboardingStatus class

Constructors

OnboardingStatus({String? currentStep, required List<String> completedSteps, required List<String> remainingSteps, required bool completed, DateTime? completedAt})
OnboardingStatus.fromJson(Map<String, dynamic> json)
factory

Properties

completed bool
final
completedAt DateTime?
final
completedSteps List<String>
final
currentStep String?
final
hashCode int
The hash code for this object.
no setterinherited
remainingSteps List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited