ReferralCode class

Constructors

ReferralCode({required String id, required String code, required String ownerId, int usesCount = 0, int? maxUses, DateTime? expiresAt, required DateTime createdAt})
ReferralCode.fromJson(Map<String, dynamic> json)
factory

Properties

code String
final
createdAt DateTime
final
expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
maxUses int?
final
ownerId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usesCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited