CurrencyBalance class
Constructors
- CurrencyBalance({required String currencyId, required String key, required int balance, required DateTime updatedAt})
-
CurrencyBalance.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited