FeedResponse class
Constructors
-
FeedResponse({required List<
FeedItem> data, String? nextCursor}) -
FeedResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
data
→ List<
FeedItem> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextCursor → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited