ReviewsNamespace class
Constructors
- ReviewsNamespace(AmbaBindings _bindings)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
{required String targetType, required String targetId, required double rating, String? title, String? body}) → Future< Review> -
delete(
String id) → Future< void> -
list(
String targetType, String targetId) → Future< List< Review> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String id, {double? rating, String? title, String? body}) → Future< Review>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited