SyncPullResult class
Reply from sync.pullChanges — the batch of changes newer than
the supplied checkpoint, the new cursor, and whether more pages
are available.
Constructors
-
SyncPullResult({required List<
SyncChange> changes, required String checkpointToken, bool hasMore = false}) -
SyncPullResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
changes
→ List<
SyncChange> -
final
- checkpointToken → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited